#ifndef _PRINT_INS_
#define _PRINT_INS_

int print_INS (std::vector<Eigen::Vector3d> &points, std::vector<Eigen::Vector3d> &enu_points)
{
    // Convert latitude and longitude to ENU coordinates
    // Assuming the first point is the reference point (0, 0) in ENU
    std::vector<Eigen::Vector3d> points_xyz;
    for (const auto &point : points)
      {
        double phi = point[1];
        double lambda = point[2];
        Eigen::Vector3d input(phi, lambda, 0.0);
        Eigen::Vector3d output = cart_Geo(input, 1);
        points_xyz.push_back(output);
      }

    // first point
    Eigen::Vector3d reference_point;
    reference_point << points.front()[1], points.front()[2], 0.0;
    Eigen::Vector3d reference_point_xyz = points_xyz.front();
    std::vector<Eigen::Vector3d> points_dxyz;
    for (const auto &point : points_xyz)
      {
        Eigen::Vector3d dxyz = point - reference_point_xyz;
        Eigen::Vector3d enu = cart_to_enu(dxyz, reference_point);
        points_dxyz.push_back(dxyz);
        enu_points.push_back(enu);
      }
    return 0;
}

void fillPoints(std::vector<Eigen::Vector3d> &points, Eigen::MatrixXf &position_x_matrix, Eigen::MatrixXf &position_y_matrix, int start_frame, int end_frame)
{
    for (int i = start_frame; i < end_frame; i++) 
    {
        points.push_back(Eigen::Vector3d(0.0, double(position_y_matrix(i, 0)) * (M_PI / 180.), double(position_x_matrix(i, 0)) * (M_PI / 180.)));   
    }
    return;
}

void extractMetricCoordinates(std::vector<Eigen::Vector3d> &enu_points, std::vector<double> &e_coordinates, std::vector<double> &n_coordinates)
{    
    for (const auto &point : enu_points)
    {
        if (pow(((point[0], 2) + pow(point[1], 2)), 0.5) < 5000)
        {
            e_coordinates.push_back(point[0]);
            n_coordinates.push_back(point[1]);
        }
    }
    return;
}

#endif

